- D2
Observation points
- H1
Regression function for D1
- phi
hyperparameters. Default value of NULL only to be
used in Edash.theta.toy() when fast.but.opaque is TRUE
- x
lat/long point (for Edash.theta.toy)
- t.vec
Matrix whose rows are parameter values (for Edash.theta.toy)
- k
Integer specifying column (for Edash.theta.toy)
- give.mean
In E.theta.toy(), Boolean, with default TRUE meaning to return
the mean (expectation), and FALSE meaning to return the “variance”
- fast.but.opaque
In Edash.theta.toy(), Boolean, with
default FALSE meaning to use a slow but clear method. If
TRUE, use faster code but parameters a and b must then be specified
- a
Constant term, needed if fast.but.opaque is
TRUE:
\(\left(V_\theta^{-1}+2\Omega_t\right)^{-1}V_\theta^{-1}m_\theta\).
Specifying a in advance saves execution time
- b
Linear term, needed if fast.but.opaque is TRUE:
\(2\left(V_\theta^{-1}+2\Omega_t\right)^{-1}\Omega_t\)
(multiplied by t[k,] in Edash.theta.toy()).
- x1
In E.theta.toy(g=F,...), the value of x in
\(h_1(x,\theta)\). The default value is NULL
because in simple cases such as that implemented here, the output is
independent of x1 and x2
- x2
In E.theta.toy(g=F,...), the value of x in
\(h_1(x,\theta)\)